import store from '@/store'
import { triggerWechatFriendPushTask, TriggerUserLabelTask, GetContactInfoTask } from '@/api/webSocketApi'
import { Message } from 'element-ui'

function taskResultMap(message) {
  switch (message.TaskType) {
    // 通过搜索号码添加客户返回 ok
    case 'AddCustomerFromSearchTask':
      store.dispatch('tools/UpdateAddCustomerFromSearchTask', {
        ...message,
        result: message.Success ? '已执行' : message.ErrMsg,
        TaskId: Number(message.TaskId)
      })
      break
    // 通过微信好友添加客户返回 ok
    case 'AddCustomerFromWxTask':
      if (message.Success) {
        // 获取最新的好友列表
        triggerWechatFriendPushTask(message.WxId)
        // 如果好友很多建议改为修改本地数据
      }
      break
    // 群管理结果通知 ok
    case 'ChatRoomActionTask':
      break
    // 客户打（移除）标签的操作 ok
    case 'UserLabelSetTask':
      GetContactInfoTask(message.WxId, message.TaskId)
      break
    // 删除个人标签
    case 'UserLabelDelTask':
      TriggerUserLabelTask(message.WxId)
      break
    // 删除朋友圈结果 ok
    case 'DelSnsTask':
      if (message.Success) {
        store.commit('circle/UPDATE_CIRCLES_BY_DELETE', message)
      }
      break
    // 朋友圈点赞结果通知 ok
    case 'SnsLikeTask':
      break
    // 发消息
    case 'TalkToFriendTask':
      break
    // 手机任务
    case 'PhoneActionTask':
      break
    // 通过新客户验证 ok
    case 'AcceptCustomerTask':
      store.commit('tools/UPDATE_NEW_FRIENDS')
      break
    default:
      console.log('taskResultMap', message)
      Message({
        type: message.Success ? 'success' : 'warning',
        message: message.Success ? '任务执行成功！' : '任务执行失败！',
        duration: 2000
      })
      break
  }
}
export default {
  taskResultMap
}
